@@ -496,17 +496,18 @@ class RedisLibraryKeywords(object):
         return [i for i, j in enumerate(redis_conn.lrange(list_name, 0, -1)) if j == str.encode(item)]
 
     @keyword('Get All Match Keys')
-    def get_all_match_keys(self, redis_conn, key):
+    def get_all_match_keys(self, redis_conn, key, count=100):
         """ Get all key that matches with specific keyword
 
         Arguments:
             - redis_conn: Redis connection object
-            - keyword: String keyword to find may contain wildcard.
+            - key: String keyword to find may contain wildcard.
+            - count: Element number of returns
 
         Examples:
-        | @{key_list}=   | Get All Match Keys | ${redis_conn} | BARCODE* |
+        | @{key_list}=   | Get All Match Keys | ${redis_conn} | BARCODE* | 1000 |
         """
-        return redis_conn.keys(key)
+        return redis_conn.scan(0, key, count)[1]
 
     @keyword('Delete Item From List Redis')
     def delete_item_from_list_redis(self, redis_conn, list_name, index, item=None):
